==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/da.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'da', {
	button: {
		title: 'Egenskaber for knap',
		text: 'Tekst',
		type: 'Type',
		typeBtn: 'Knap',
		typeSbm: 'Send',
		typeRst: 'Nulstil'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Egenskaber for afkrydsningsfelt',
		radioTitle: 'Egenskaber for alternativknap',
		value: 'Værdi',
		selected: 'Valgt'
	},
	form: {
		title: 'Egenskaber for formular',
		menu: 'Egenskaber for formular',
		action: 'Handling',
		method: 'Metode',
		encoding: 'Kodning (encoding)'
	},
	hidden: {
		title: 'Egenskaber for skjult felt',
		name: 'Navn',
		value: 'Værdi'
	},
	select: {
		title: 'Egenskaber for liste',
		selectInfo: 'Generelt',
		opAvail: 'Valgmuligheder',
		value: 'Værdi',
		size: 'Størrelse',
		lines: 'Linjer',
		chkMulti: 'Tillad flere valg',
		opText: 'Tekst',
		opValue: 'Værdi',
		btnAdd: 'Tilføj',
		btnModify: 'Redigér',
		btnUp: 'Op',
		btnDown: 'Ned',
		btnSetValue: 'Sæt som valgt',
		btnDelete: 'Slet'
	},
	textarea: {
		title: 'Egenskaber for tekstboks',
		cols: 'Kolonner',
		rows: 'Rækker'
	},
	textfield: {
		title: 'Egenskaber for tekstfelt',
		name: 'Navn',
		value: 'Værdi',
		charWidth: 'Bredde (tegn)',
		maxChars: 'Max. antal tegn',
		type: 'Type',
		typeText: 'Tekst',
		typePass: 'Adgangskode',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/da.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'da', {
	button: {
		title: 'Egenskaber for knap',
		text: 'Tekst',
		type: 'Type',
		typeBtn: 'Knap',
		typeSbm: 'Send',
		typeRst: 'Nulstil'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Egenskaber for afkrydsningsfelt',
		radioTitle: 'Egenskaber for alternativknap',
		value: 'Værdi',
		selected: 'Valgt',
		required: 'Påkrævet'
	},
	form: {
		title: 'Egenskaber for formular',
		menu: 'Egenskaber for formular',
		action: 'Handling',
		method: 'Metode',
		encoding: 'Kodning (encoding)'
	},
	hidden: {
		title: 'Egenskaber for skjult felt',
		name: 'Navn',
		value: 'Værdi'
	},
	select: {
		title: 'Egenskaber for liste',
		selectInfo: 'Generelt',
		opAvail: 'Valgmuligheder',
		value: 'Værdi',
		size: 'Størrelse',
		lines: 'Linjer',
		chkMulti: 'Tillad flere valg',
		required: 'Påkrævet',
		opText: 'Tekst',
		opValue: 'Værdi',
		btnAdd: 'Tilføj',
		btnModify: 'Redigér',
		btnUp: 'Op',
		btnDown: 'Ned',
		btnSetValue: 'Sæt som valgt',
		btnDelete: 'Slet'
	},
	textarea: {
		title: 'Egenskaber for tekstboks',
		cols: 'Kolonner',
		rows: 'Rækker'
	},
	textfield: {
		title: 'Egenskaber for tekstfelt',
		name: 'Navn',
		value: 'Værdi',
		charWidth: 'Bredde (tegn)',
		maxChars: 'Max. antal tegn',
		required: 'Påkrævet',
		type: 'Type',
		typeText: 'Tekst',
		typePass: 'Adgangskode',
		typeEmail: 'E-mail',
		typeSearch: 'Søg',
		typeTel: 'Telefon nummer',
		typeUrl: 'URL'
	}
} );
